@@ -1,6 +1,6 @@
-/* $Id: hparser.h,v 2.18 2001/03/30 08:10:36 gisle Exp $
+/* $Id: hparser.h,v 2.24 2002/03/17 20:07:57 gisle Exp $
  *
- * Copyright 1999-2001, Gisle Aas
+ * Copyright 1999-2002, Gisle Aas
  * Copyright 1999-2000, Michael A. Chase
  *
  * This library is free software; you can redistribute it and/or
@@ -35,10 +35,12 @@ enum event_id {
     E_END,
     E_TEXT,
     E_PROCESS,
+    E_START_DOCUMENT,
+    E_END_DOCUMENT,
     E_DEFAULT,
     /**/
     EVENT_COUNT,
-    E_NONE,  /* used for reporting skipped text (non-events) */
+    E_NONE   /* used for reporting skipped text (non-events) */
 };
 typedef enum event_id event_id_t;
 
@@ -50,6 +52,8 @@ static char* event_id_str[] = {
     "end",
     "text",
     "process",
+    "start_document",
+    "end_document",
     "default",
 };
 
@@ -80,6 +84,9 @@ struct p_state {
     STRLEN pend_text_line;
     STRLEN pend_text_column;
 
+    /* skipped text is accumulated here */
+    SV* skipped_text;
+
 #ifdef MARKED_SECTION
     /* marked section support */
     enum marked_section_t ms;
@@ -92,6 +99,8 @@ struct p_state {
     bool strict_names;
     bool xml_mode;
     bool unbroken_text;
+    bool attr_encoded;
+    bool case_sensitive;
 
     /* other configuration stuff */
     SV* bool_attr_val;
@@ -108,6 +117,7 @@ struct p_state {
 
     /* cache */
     HV* entity2char;            /* %HTML::Entities::entity2char */
+    SV* tmp;
 };
 typedef struct p_state PSTATE;
 
