@@ -1,6 +1,6 @@
 package HTML::Entities;
 
-# $Id: Entities.pm,v 1.19 2000/12/04 16:20:36 gisle Exp $
+# $Id: Entities.pm,v 1.23 2001/11/05 21:23:21 gisle Exp $
 
 =head1 NAME
 
@@ -24,8 +24,8 @@ character entities.  The module provides the following functions:
 =item decode_entities($string)
 
 This routine replaces HTML entities found in the $string with the
-corresponding ISO-8859/1 (or with perl-5.6 Unicode) character.
-Unrecognized entities are left alone.
+corresponding ISO-8859/1 (or with perl-5.7 or better Unicode)
+character.  Unrecognized entities are left alone.
 
 =item encode_entities($string, [$unsafe_chars])
 
@@ -55,7 +55,7 @@ corresponding entities.
 
 =head1 COPYRIGHT
 
-Copyright 1995-2000 Gisle Aas. All rights reserved.
+Copyright 1995-2001 Gisle Aas. All rights reserved.
 
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -70,10 +70,10 @@ require 5.004;
 require Exporter;
 @ISA = qw(Exporter);
 
-@EXPORT = qw(encode_entities decode_entities);
+@EXPORT = qw(encode_entities decode_entities _decode_entities);
 @EXPORT_OK = qw(%entity2char %char2entity);
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.19 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.23 $ =~ /(\d+)\.(\d+)/);
 sub Version { $VERSION; }
 
 require HTML::Parser;  # for fast XS implemented decode_entities
@@ -85,6 +85,7 @@ require HTML::Parser;  # for fast XS implemented decode_entities
 'gt'    => '>',  # greater than
 'lt'    => '<',  # less than
  quot   => '"',  # double quote
+ apos   => "'",  # single quote
 
  # PUBLIC ISO 8879-1986//ENTITIES Added Latin 1//EN//HTML
  AElig	=> '',  # capital AE diphthong (ligature)
@@ -188,7 +189,7 @@ require HTML::Parser;  # for fast XS implemented decode_entities
 'times' => '',    # times is a keyword in perl
  divide => '',
 
- ( $] >= 5.006 ? (
+ ( $] > 5.007 ? (
    OElig    => chr(338),
    oelig    => chr(339),
    Scaron   => chr(352),
@@ -349,6 +350,7 @@ require HTML::Parser;  # for fast XS implemented decode_entities
 while (my($entity, $char) = each(%entity2char)) {
     $char2entity{$char} = "&$entity;";
 }
+delete $char2entity{"'"};  # only one-way decoding
 
 # Fill inn missing entities
 for (0 .. 255) {
@@ -394,7 +396,7 @@ sub encode_entities
 	&{$subst{$_[1]}}($$ref);
     } else {
 	# Encode control chars, high bit chars and '<', '&', '>', '"'
-	$$ref =~ s/([^\n\t !\#\$%\'-;=?-~])/$char2entity{$1} || num_entity($1)/ge;
+	$$ref =~ s/([^\n\r\t !\#\$%\'-;=?-~])/$char2entity{$1} || num_entity($1)/ge;
     }
     $$ref;
 }
